import argparse
import sys
import logging

from postinstall import register
from postinstall import register_svm
from postinstall import unregister_svm
from postinstall import delete_mps_records
from constants import PrecheckPlugin
from constants import FORMAT
from constants import DATEFMT
from precheck.plugin_base import PluginBase

# initialize plugins for precheck
PRECHECK_PLUGINS = {p.id: p for p in PluginBase.plugins}

# Set up Logging
logging.basicConfig(format=FORMAT, datefmt=DATEFMT, level=logging.INFO)
logger = logging.getLogger(__name__)

def main():
    parser = argparse.ArgumentParser(description='Python utilities module for Malware Prevention')
    parser.add_argument('--register-mps-feature', action="store_true", required=False,
                        help="Invoke API on NSX manager to register Malware Prevention")
    parser.add_argument('--register-svm', action="store_true", required=False,
                            help="Invoke API on NSX manager to register SVM for MPS")
    parser.add_argument('--unregister-mps-feature', action="store_true", required=False,
                            help="Invoke API on NSX manager to unregister Malware Prevention")
    parser.add_argument('--delete-kafka-offset', action="store_true", required=False,
                        help="Delete kafka offset entries in database")
    parser.add_argument('--validate-license', action="store_true", required=False,
                            help="Invoke API on NSX manager to retrieve licenses and "
                                 "validate if minimum requirements are met")
    parser.add_argument('--validate-capacity', action="store_true", required=False,
                            help="Invoke capacity API to check if required capacity to install Malware Prevention feature is met")
    args = parser.parse_args()

    if args.register_mps_feature:
        logging.info("Registering Malware Prevention feature.")
        register.ui_plugin()
        register.cluster()
    elif args.register_svm:
        logging.info("Register SVM OVF")
        register_svm.create_service_definition()
    elif args.unregister_mps_feature:
        logging.info("Unregister Malware prevention feature")
        register.ui_plugin(unregister=True)
        unregister_svm.delete_service_definition()
        delete_mps_records.delete_records()
        register.cluster(unregister=True)
    elif args.delete_kafka_offset:
        logging.info("Delete kafka offset")
        delete_mps_records.delete_kafka_offset()
    elif args.validate_license:
        license_plugin = PRECHECK_PLUGINS[PrecheckPlugin.LICENSE]()
        license_plugin.check()
    elif args.validate_capacity:
        capacity_plugin = PRECHECK_PLUGINS[PrecheckPlugin.CAPACITY]()
        capacity_plugin.check()
    else:
        parser.print_help()

try:
    main()
except Exception as e:
    logging.exception(e)
    sys.exit(1)
