# keystore/truststore constants
INCLUSTER_KEYSTORE_PATH = "/etc/ams/store/keystore.p12"
INCLUSTER_TRUSTSTORE_PATH = "/etc/ams/store/truststore.p12"
INCLUSTER_CA_PATH = "/etc/ams/store/ca.crt"
EGRESS_KEYSTORE_PATH = "/etc/ams/egress-store/egress-keystore.p12"

# API endpoints/hosts
CLUSTER_API_HOST = "cluster-api"
MALWARE_PREVENTION_UI_HOST = "malware-prevention-ui"
NSX_MANAGER_HOST = "external-nsx-manager"
SA_WEB_SERVICES_HOST = "sa-web-services"
MONITOR_API_HOST = "monitor"

# Case should match response from Monitor API
class PlatformFormFactor:
    ADVANCED = "ADVANCED"
    STANDARD = "STANDARD"
    EVALUATION = "EVALUATION"

# REST headers
BASE_HEADERS = {'Content-Type': 'application/json'}

# TABLE NAMES
INSPECTION_EVENTS = "inspection_events"
NON_BENIGN_TABLE = "non_benign_table"
SUMMARY_TABLE = "summary_table"
INTERCEPTED_ENTITIES = "intercepted_entities"
CLIENT_CACHE_MAPPING = "client_cache_mapping"

SA_CONFIGURATION = "sa_configurations"
ALLOW_LIST_TABLE = "allow_list_table"
HTTP_HEADER = "http_header"
REPUTATION_FAILED_HASH = "reputation_failed_hash"
REPUTATION_PUBSUB_CONFIG = "reputation_pubsub_config"
REPUTATION_UPDATE_MARKER = "reputation_update_marker"
REPUTATION_QUERY_METADATA = "reputation_query_metadata"
REPUTATION_CLOUD_SERVICE_CONFIG = "reputation_cloud_service_config"
UPDATE_QUEUE = "update_queue"
UNAVAILABLE_QUEUE_TABLE = "unavailable_queue_table"
KAFKA_OFFSET = "kafka_offset"

HTTPS = "https://"
NSX_SVM_APPLIANCE = "nsx-svm-appliance-"
NAMESPACE = "nsxi-platform"
INSTANCE_NAME = "malware-prevention"
UI_POD_LABEL_SELECTOR = 'app.kubernetes.io/name=%s,app.kubernetes.io/instance=%s,vmware/version={chart_version}' % (MALWARE_PREVENTION_UI_HOST, INSTANCE_NAME)
WEB_SERVICE_POD_LABEL_SELECTOR = 'app.kubernetes.io/component=%s,app.kubernetes.io/name=%s,app.kubernetes.io/instance=%s,vmware/version={chart_version}' % (SA_WEB_SERVICES_HOST, SA_WEB_SERVICES_HOST, INSTANCE_NAME)
MALWARE_PREVENTION_ENABLED = "is_malware_prevention_enabled"
RETRY_COUNT = 3

# Logging
FORMAT = '%(asctime)s %(levelname)s: %(message)s'
DATEFMT = '%m/%d/%Y %I:%M:%S %p'

VALID_LICENSE_LIST = [
    "VMware Firewall with Advanced Threat Prevention",
    "VMware Advanced Threat Prevention",
    "NSX Distributed Firewall with Advanced Threat Prevention",
    "NSX Advanced with Advanced Threat Prevention",
    "NSX Enterprise Plus with Advanced Threat Prevention",
    "NSX Firewall with Advanced Threat Prevention"
]

class Url:
    class InCluster:
        REGISTER_UI_PLUGIN_URL = "https://{service_host}:{service_port}/post-deployment"
        POST_REPORT_PRECHECK = "https://{service_host}:{service_port}/report/precheck"
        LIST_ALL_FEATURES = "https://{service_host}:{service_port}/list-all-features"
        GET_PLATFORM_STATUS = "https://{service_host}:{service_port}/api/v1/platform/monitor/platform/status"
        VALIDATE_CAPACITY = "https://{service_host}:{service_port}/features/malware-prevention/capacity/validate"
        SYNC_SYSTEM_SVM_OVF = "https://{service_host}/api/v1/malware-prevention/system/svm-spec?action=sync"

    class Egress:
        SERVICE_DEFINITION_URL = "https://{service_host}:443/api/v1/serviceinsertion/services/".format(
            service_host=NSX_MANAGER_HOST)
        GET_NSX_VERSION = "https://{service_host}:443/api/v1/node/version/".format(
            service_host=NSX_MANAGER_HOST)
        GET_CLUSTER_REGISTRATION = "https://{service_host}:443/policy/api/v1/infra/sites/napp/registration".format(
            service_host=NSX_MANAGER_HOST)
        PATCH_CLUSTER_REGISTRATION = "https://{service_host}:443/policy/api/v1/infra/sites/napp/registration/{cluster_id}"

class CheckStatus:
    SUCCESS = "SUCCESS"
    FAILED = "FAILED"
    WARNING = "WARNING"
    SKIPPED = "SKIPPED"
    INPROGRESS = "INPROGRESS"
    STOPPING = "STOPPING"
    STOPPED = "STOPPED"

class Feature:
    MALWAREPREVENTION = "malware-prevention"


class PrecheckPlugin:
    LICENSE = "license"
    CAPACITY = "capacity"


class CapacityRemaining:
    # Minimum 15% is required to not trigger high usage alarm.
    # MPS scheduled jobs in itself shouldn't require significant resources
    CPU = 15
    MEMORY = 15
    # For eval, alarms are OKAY. Setting buffer capacity as 5%
    EVAL_CPU = 5
    EVAL_MEMORY = 5
