import os
import logging

import constants
try:
    import psycopg
except ImportError as i:
    logging.error("Unable to find python-postgresql driver module")


TRUNCATE_STATEMENT = "TRUNCATE TABLE "
CASCADE_STATEMENT = " CASCADE "


def delete_table_records(cursor, table_name, retry=None):
    if retry is None:
        retry = 3
    try:
        logging.debug("Trying to delete from table: {} with retry: {}".format(table_name, str(retry)))
        cursor.execute(TRUNCATE_STATEMENT + table_name + CASCADE_STATEMENT)
        logging.info("Successfully deleted records from table: {}".format(table_name))
    except Exception as e:
        if retry == 0:
            raise e
        logging.exception(e)
        logging.exception("Delete from table: {} failed hence retrying",table_name)
        delete_table_records(cursor, table_name, retry - 1)


def delete_records():
    logging.info("Trying to delete records from tables related to malware prevention")
    connection = None
    try:
        host = os.environ.get("POSTGRES_HOST", "postgresql-ha-pgpool")
        database = os.environ.get("POSTGRES_DATABASE", "malwareprevention")
        username = os.environ.get("POSTGRES_USERNAME", "postgres")
        password = os.environ.get("POSTGRES_PASSWORD", "postgres")

        connection = psycopg.connect("dbname={} user={} password={} host={}".format(database, username, password, host))

        cursor = connection.cursor()

        delete_table_records(cursor, constants.INSPECTION_EVENTS)
        delete_table_records(cursor, constants.HTTP_HEADER)
        delete_table_records(cursor, constants.NON_BENIGN_TABLE)
        delete_table_records(cursor, constants.SUMMARY_TABLE)
        delete_table_records(cursor, constants.INTERCEPTED_ENTITIES)
        delete_table_records(cursor, constants.ALLOW_LIST_TABLE)
        delete_table_records(cursor, constants.CLIENT_CACHE_MAPPING)
        delete_table_records(cursor, constants.REPUTATION_CLOUD_SERVICE_CONFIG)
        delete_table_records(cursor, constants.REPUTATION_PUBSUB_CONFIG)
        delete_table_records(cursor, constants.REPUTATION_FAILED_HASH)
        # This is a statically inserted record at time of DB init which should not be deleted.
        # Keeping this commented so that we are aware of all tables
        # delete_table_records(cursor, constants.REPUTATION_UPDATE_MARKER)
        delete_table_records(cursor, constants.UPDATE_QUEUE)
        delete_table_records(cursor, constants.UNAVAILABLE_QUEUE_TABLE)

        connection.commit()
        cursor.close()
    except Exception as e:
        logging.exception(e)
        logging.exception("Exception occurred while deleting records from database, hence please delete manually")
    finally:
        if connection is not None:
            connection.close()

def delete_kafka_offset():
    logging.info("Trying to delete kafka offset from tables related to malware prevention")
    connection = None
    try:
        host = os.environ.get("POSTGRES_HOST", "postgresql-ha-pgpool")
        database = os.environ.get("POSTGRES_DATABASE", "malwareprevention")
        username = os.environ.get("POSTGRES_USERNAME", "postgres")
        password = os.environ.get("POSTGRES_PASSWORD", "postgres")

        connection = psycopg.connect("dbname={} user={} password={} host={}".format(database, username, password, host))
        cursor = connection.cursor()
        delete_table_records(cursor, constants.KAFKA_OFFSET)

        connection.commit()
        cursor.close()
    except Exception as e:
        logging.exception(e)
        logging.exception("Exception occurred while deleting records from database, hence please delete manually")
    finally:
        if connection is not None:
            connection.close()
