import os
import logging

from constants import CLUSTER_API_HOST
from constants import NSX_MANAGER_HOST
from constants import MALWARE_PREVENTION_ENABLED
from constants import RETRY_COUNT
from constants import Url
from utils import requests_wrapper

def ui_plugin(unregister=False):
    try:
        # create request parameters
        cluster_api_port = os.environ["CLUSTER_API_SERVICE_PORT"]
        url = Url.InCluster.REGISTER_UI_PLUGIN_URL.format(
            service_host=CLUSTER_API_HOST,
            service_port=cluster_api_port)
        req_data = {
            "service_names": ["malware_prevention"],
            "action": "unregister" if unregister else "register",
        }
        logging.info("Calling Malware Prevention UI plugin (un)registration API on cluster-api service")
        requests_wrapper.incluster_request('POST', url, data=req_data)
    except Exception as e:
        logging.exception(e)
        raise

def get_napp_cluster_information():
    try:
        # get cluster-id from NSX
        url = Url.Egress.GET_CLUSTER_REGISTRATION
        logging.info("Calling GET NAPP cluster registration.")
        response = requests_wrapper.egress_request("GET", url)
        json_response = response.json()
        napp_registration_results = json_response["napp_registration_results"]
        if napp_registration_results is not None and len(napp_registration_results) > 0:
            #There is ony 1 NAPP instance registered with NSX. Hence, getting the first item
            cluster_item = napp_registration_results[0]
            return cluster_item
        else:
            raise Exception("NSX Application Platform cluster registration results not found")
    except Exception as e:
        logging.exception(e)
        logging.error("Get NAPP cluster registration API failed")
        raise

def get_clusterid_and_set_mps_status(unregister=False, retry=None):
    if retry is None:
        retry = RETRY_COUNT
    try:
        cluster_info = get_napp_cluster_information()
        if MALWARE_PREVENTION_ENABLED in cluster_info:
            logging.info("%s key exists. Calling PATCH API to set MPS feature status.",MALWARE_PREVENTION_ENABLED)
            cluster_id = cluster_info["cluster_id"]
            # PATCH is_malware_prevention_enabled for the given cluster_id
            if not cluster_id:
                raise Exception("NSX Application Platform cluster id not found")
            url = Url.Egress.PATCH_CLUSTER_REGISTRATION.format(
                service_host=NSX_MANAGER_HOST,
                cluster_id=cluster_id)
            req_data = {
                "cluster_id": cluster_id,
                MALWARE_PREVENTION_ENABLED: False if unregister else True
            }
            requests_wrapper.egress_request("PATCH", url, data=req_data, headers={'X-Allow-Overwrite': 'true'})
        else :
            # This is the case where NSX version is older than 4.2
            logging.info("%s key does not exists. Hence, not calling PATCH API",MALWARE_PREVENTION_ENABLED)
    except Exception as e:
        if retry == 1:
            raise e
        logging.exception(e)
        logging.error("Cluster Registration PATCH Api failed. Hence retrying")
        get_clusterid_and_set_mps_status(unregister, retry -1)
def cluster(unregister=False):
    try:
        get_clusterid_and_set_mps_status(unregister, RETRY_COUNT)
    except Exception as e:
        logging.exception(e)
        raise

