import json
import os
import logging

import constants
from constants import Url
from utils import requests_wrapper

def delete_service_definition():
    try:
        logging.info("Get MPS service definition.")
        response = requests_wrapper.egress_request('GET', Url.Egress.SERVICE_DEFINITION_URL)
        service_response = response.json()
        result_count = service_response['result_count']
        logging.debug("Result count : ",result_count)
        if(result_count < 1):
           logging.info("No service definition found.")
           return

        results = service_response['results']
        for result in results:
            func = result['functionalities']
            exists = 'MPS' in func
            logging.debug("MPS Service definition exists")
            serviceId = result['id']
            break

        if not exists:
            logging.info("No MPS service definition found.")
            return

        logging.debug("Service id : ",serviceId)
        logging.debug("Get the solution configuration for MPS")
        r = requests_wrapper.egress_request('GET', Url.Egress.SERVICE_DEFINITION_URL+serviceId+"/solution-configs")
        solution_response = r.json()
        count = solution_response['result_count']
        if(count < 1):
           logging.debug("No solution configuration found for MPS. Hence, not deleting extended solution config")
        else :
           solutionConfigs = solution_response['results']
           solutionConfig = solutionConfigs[0]
           solutionId = solutionConfig['id']
           logging.debug("Solution Id : ",solutionId)
           logging.info("Deleting the extended solution configuration")
           requests_wrapper.egress_request('DELETE', Url.Egress.SERVICE_DEFINITION_URL+serviceId+"/solution-configs/"+solutionId+"/extended-solution-config")

        logging.info("Deleting the service definition")
        requests_wrapper.egress_request('DELETE', Url.Egress.SERVICE_DEFINITION_URL+serviceId)
    except Exception as e:
        logging.exception(e)
        raise
