import os
import logging

from constants import CapacityRemaining
from constants import CheckStatus
from constants import Feature
from constants import PrecheckPlugin
from constants import PlatformFormFactor
from constants import Url
from constants import CLUSTER_API_HOST
from constants import MONITOR_API_HOST
from precheck.plugin_base import PluginBase
from utils import requests_wrapper

class PluginCapacity(PluginBase):
    id = PrecheckPlugin.CAPACITY
    name = "feature.precheck.capacityName"
    desc = "feature.precheck.capacityDesc"
    feature = Feature.MALWAREPREVENTION

    def check(self):
        try:
            self.report_check_status(CheckStatus.INPROGRESS, "")

            # Invoke Monitor API to fetch NAPP form factor
            monitor_json_response = self.get_napp_form_factor()

            # create request parameters
            cluster_api_port = os.environ["CLUSTER_API_SERVICE_PORT"]
            url = Url.InCluster.VALIDATE_CAPACITY.format(
                service_host=CLUSTER_API_HOST,
                service_port=cluster_api_port)
            req_data = self.get_capacity_request(monitor_json_response)

            logging.info("Calling cluster-api to check if capacity exists to deploy feature")
            response = requests_wrapper.incluster_request('POST', url, data=req_data)
            json_response = response.json()
            logging.info(json_response)

            if json_response["can_deploy"]:
                # can deploy == true, mark success
                self.report_check_status(CheckStatus.SUCCESS, "feature.precheck.capacityPassReason")
            else:
                # can't deploy - return reason
                self.report_check_status(
                    CheckStatus.FAILED,
                    "feature.precheck.capacityFailReason: {reason}".format(reason=json_response["reason"]))
        except Exception as e:
            self.report_check_status(
                CheckStatus.FAILED, "feature.precheck.nappApiInvocationFailedReason")
            logging.exception(e)
            raise

    def get_napp_form_factor(self):
        monitor_api_port = os.environ["MONITOR_SERVICE_PORT"]
        url = Url.InCluster.GET_PLATFORM_STATUS.format(
            service_host=MONITOR_API_HOST,
            service_port=monitor_api_port)
        logging.info("Calling Monitor service to get platform information")
        monitor_response = requests_wrapper.incluster_request('GET', url)
        monitor_json_response = monitor_response.json()
        logging.info(monitor_json_response)
        return monitor_json_response

    def get_capacity_request(self, monitor_json_response):
        if monitor_json_response["form_factor"] == PlatformFormFactor.EVALUATION:
            # EVAL FF is tight on resources - 15% buffer does not work
            # Dropping it to 5%. alarms are OKAY
            req_data = {
                "remaining_cpu_percent": CapacityRemaining.EVAL_CPU,
                "remaining_memory_percent": CapacityRemaining.EVAL_MEMORY
            }
        else:
            req_data = {
                "remaining_cpu_percent": CapacityRemaining.CPU,
                "remaining_memory_percent": CapacityRemaining.MEMORY
            }
        return req_data