import json
import os
import base64
import logging

import constants
from utils import requests_pkcs12

class TlsParamsIncluster:
    def __init__(self):
        self.verify = constants.INCLUSTER_CA_PATH
        self.pkcs12_filename = constants.INCLUSTER_KEYSTORE_PATH
        self.pkcs12_password = os.environ["SSL_CERTIFICATE_PASSWORD"]


class TlsParamsEgress:
    def __init__(self):
        self.verify = False
        self.pkcs12_filename = constants.EGRESS_KEYSTORE_PATH
        self.pkcs12_password = os.environ["EGRESS_CERTIFICATE_PASSWORD"]

def get_encoded_user_header():
    nsx_role_header = "enterprise_admin"
    string_bytes = nsx_role_header.encode("ascii")

    base64_bytes = base64.b64encode(string_bytes)
    encoded_string = base64_bytes.decode("ascii")
    return encoded_string


def _invoke_requests(method, url, data=None, headers=None, egress=False):
    try:
        # setup TLS params
        tls_params = TlsParamsEgress() if egress else TlsParamsIncluster()

        # append headers if provided, else use defaults
        if headers:
            headers.update(constants.BASE_HEADERS)
        else:
            headers = constants.BASE_HEADERS
        logging.info("calling {method} {url} {data}".format(
            method=method, url=url, data=data))
        # encode data to UTF-8
        encoded_data = json.dumps(data).encode("utf-8")
        r = requests_pkcs12.request(
            method, url, data=encoded_data, headers=headers,
            verify=tls_params.verify,
            pkcs12_filename=tls_params.pkcs12_filename,
            pkcs12_password=tls_params.pkcs12_password)
        if not r.ok:
            raise Exception("REST FAILED: {reason}"
                            .format(reason=r.reason))
        else:
            logging.info("REST API executed successfully.")
            return r
    except Exception:
        raise


def incluster_request(method, url, data=None, headers=None):
    role_header = get_encoded_user_header()
    rbac_in_cluster_header = {'X-NSX-ROLES': role_header}
    if headers:
        headers.update(rbac_in_cluster_header)
    else:
        headers = rbac_in_cluster_header
    return _invoke_requests(method=method, url=url, data=data,
                            headers=headers, egress=False)


def egress_request(method, url, data=None, headers=None):
    return _invoke_requests(method=method, url=url, data=data,
                            headers=headers, egress=True)
